@@ -17,7 +17,6 @@ OC.L10N.register(
     "Export" : "Çıxarış",
     "Delete" : "Sil",
     "Unshare" : "Paylaşımı durdur",
-    "Save" : "Saxla",
     "An empty name is not allowed." : "Boş ada izin verilmir.",
     "Name" : "Ad",
     "Deleted" : "Silinib",
@@ -27,7 +26,6 @@ OC.L10N.register(
     "Close" : "Bağla",
     "_%n Completed Task_::_%n Completed Tasks_" : ["\"%s\" Bitmiş Tapşırıqlar","Completed Tasks"],
     "Tomorrow" : "Sabah",
-    "New List" : "Yeni Siyahı",
     "Details" : "Detallar",
     "Notes" : "Qeydlər",
     "Repeat" : "Təkrar",
