@@ -25,7 +25,6 @@ OC.L10N.register(
     "Export" : "Eksporti",
     "Delete" : "Forigi",
     "Unshare" : "Malkunhavigi",
-    "Save" : "Konservi",
     "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Tio forigos la kalendaron „{calendar}“ kaj ĉiujn ties eventojn kaj taskojn.",
     "Calendar link copied to clipboard." : "Kalendara ligilo kopiita al tondujo",
     "Calendar link could not be copied to clipboard." : "Kalendara ligilo ne eblis esti kopiita al tondujo",
@@ -49,19 +48,13 @@ OC.L10N.register(
     "Add a task due today to \"{calendar}\"…" : "Aldoni taskon kun hodiaŭa limdato al „{calendar}“...",
     "Add a current task to \"{calendar}\"…" : "Aldoni nunan taskon al „{calendar}“...",
     "Add a task to \"{calendar}\"…" : "Aldoni taskon al „{calendar}“...",
-    "Load all completed tasks." : "Ŝargi ĉiujn plenumitajn taskojn.",
     "Change sort order" : "Ŝanĝi ordigon",
     "Sort by completed state, due date, priority, start date and summary." : "Ordigi laŭ plenumstato, limdato, prioritato, komencdato kaj resumo.",
     "Start date" : "Komencdato",
-    "Sort by start date and summary." : "Ordigi laŭ komencdato kaj resumo.",
     "Due date" : "Limdato",
-    "Sort by due date and summary." : "Ordigi laŭ limdato kaj resumo.",
     "Created date" : "Krea dato",
-    "Sort by created date and summary." : "Ordigi laŭ krea dato kaj resumo.",
     "Last modified" : "Laste modifita",
-    "Sort by last-modified date and summary." : "Ordigi laŭ dato de lasta modifo kaj resumo.",
     "Completed date" : "Plenumdato",
-    "Sort by completed date." : "Ordigi laŭ plenumdato",
     "Priority" : "Prioritato",
     "Sort by priority and summary." : "Ordigi laŭ prioritato kaj resumo.",
     "Alphabetically" : "Alfabete",
@@ -79,7 +72,6 @@ OC.L10N.register(
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n plenumita tasko","%n plenumitaj taskoj"],
     "Tomorrow" : "Morgaŭ",
     "Add List…" : "Aldoni liston...",
-    "New List" : "Nova listo",
     "All day" : "Tuttage",
     "Details" : "Detaloj",
     "Select a classification" : "Elektu klasifikon",
