@@ -28,7 +28,7 @@ OC.L10N.register(
     "Export" : "Izvoz",
     "Delete" : "Izbriši",
     "Unshare" : "Prestani dijeliti",
-    "Save" : "Spremi",
+    "List name" : "Naziv popisa",
     "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Time će se izbrisati kalendar „{calendar}” i svi pripadajući događaji i zadaci.",
     "This will unshare the calendar \"{calendar}\"." : "Time će se prestati dijeliti kalendar „{calendar}“.",
     "This will delete the list \"{list}\" and all corresponding tasks." : "Time će se izbrisati popis „{list}” i svi pripadajući zadaci.",
@@ -81,20 +81,14 @@ OC.L10N.register(
     "Add a task due today to \"{calendar}\"…" : "Dodajte zadatak za danas u „{calendar}”...",
     "Add a current task to \"{calendar}\"…" : "Dodaj trenutni zadatak u „{calendar}”...",
     "Add a task to \"{calendar}\"…" : "Dodajte zadatak u „{calendar}”...",
-    "Load all completed tasks." : "Učitaj sve završene zadatke.",
     "Change sort order" : "Promijeni redoslijed razvrstavanja",
     "Relevance" : "Važnost",
     "Sort by completed state, due date, priority, start date and summary." : "Razvrstaj prema stanju, datumu dospijeća, prioritetu, datumu početka i sažetku.",
     "Start date" : "Datum početka",
-    "Sort by start date and summary." : "Razvrstaj prema datumu početka i sažetku.",
     "Due date" : "Datum dospijeća",
-    "Sort by due date and summary." : "Razvrstaj prema datumu dospijeća i sažetku.",
     "Created date" : "Datum stvaranja",
-    "Sort by created date and summary." : "Razvrstaj prema datumu stvaranja i sažetku.",
     "Last modified" : "Posljednja izmjena",
-    "Sort by last-modified date and summary." : "Razvrstaj prema datumu posljednje izmjene i sažetku.",
     "Completed date" : "Datum završetka",
-    "Sort by completed date." : "Razvrstaj prema datumu završetka.",
     "Priority" : "Prioritet",
     "Sort by priority and summary." : "Razvrstaj prema prioritetu i sažetku.",
     "Alphabetically" : "Abecedno",
@@ -134,13 +128,12 @@ OC.L10N.register(
     "Cancel" : "Odustani",
     "Create task" : "Stvori zadatak",
     "Creating the new task…" : "Stvaranje novog zadatka...",
-    "\"{task}\" was added to \"{calendar}\"" : "„{task}“ je dodano u „{calendar}“",
     "Close" : "Zatvori",
     "Open task" : "Otvori zadatak",
+    "\"{task}\" was added to \"{calendar}\"" : "„{task}“ je dodano u „{calendar}“",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n završeni zadatak","%n završenih zadataka","%n završenih zadataka"],
     "Tomorrow" : "Sutra",
     "Add List…" : "Dodaj popis…",
-    "New List" : "Novi popis",
     "All day" : "Cijeli dan",
     "Unpin" : "Otkvači",
     "Pin" : "Prikvači",
