@@ -23,7 +23,7 @@ OC.L10N.register(
     "Export" : "Ekspor",
     "Delete" : "Hapus",
     "Unshare" : "Batalkan berbagi",
-    "Save" : "Simpan",
+    "List name" : "Nama daftar",
     "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
     "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
     "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
@@ -42,7 +42,6 @@ OC.L10N.register(
     "Close" : "Tutup",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tugas Diselesaikan"],
     "Tomorrow" : "Besok",
-    "New List" : "Daftar Baru",
     "All day" : "Sepanjang hari",
     "Details" : "Detail",
     "Notes" : "Catatan",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "[Starts today]" : "[Dimulai hari ini]",
     "Set start date" : "Atur tanggal mulai",
     "Set due date" : "Atur tanggal jatuh tempo",
+    "Mark as done" : "Tandai sebagai selesai",
     "An error occurred" : "Terjadi kesalahan"
 },
 "nplurals=1; plural=0;");
