@@ -15,7 +15,6 @@ OC.L10N.register(
     "Export" : "Экспорт",
     "Delete" : "устгах",
     "Unshare" : "Түгээлтийг зогсоох",
-    "Save" : "хадгалах",
     "Name" : "Нэр",
     "Deleted" : "Устгагдсан",
     "Restore" : "Сэргээх",
@@ -24,7 +23,6 @@ OC.L10N.register(
     "Cancel" : "цуцлах",
     "Close" : "Хаах",
     "Tomorrow" : "маргааш",
-    "New List" : "шинэ жагсаалт",
     "Details" : "Дэлгэрэнгүй",
     "Notes" : "Шинэ ",
     "Reminders" : "Сануулагууд",
