@@ -23,7 +23,6 @@ OC.L10N.register(
     "Export" : "Xuất ra",
     "Delete" : "Xóa",
     "Unshare" : "Bỏ chia sẽ",
-    "Save" : "Lưu",
     "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
     "Calendar link could not be copied to clipboard." : "liên kết của lịch không thể sao chép vào bảng tạm.",
     "The name \"{calendar}\" is already used." : "Tên \"{calendar}\" đã được sử dụng.",
@@ -52,7 +51,6 @@ OC.L10N.register(
     "Close" : "Đóng",
     "Tomorrow" : "Ngày mai",
     "Add List…" : "Thêm vào danh sách…",
-    "New List" : "Danh sách mới",
     "All day" : "Cả ngày",
     "Edit title" : "Chỉnh sửa tiêu đề",
     "Details" : "Chi tiết",
