@@ -28,7 +28,7 @@ OC.L10N.register(
     "Export" : "导出",
     "Delete" : "删除",
     "Unshare" : "取消共享",
-    "Save" : "保存",
+    "List name" : "列表名称",
     "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "此操作将删除日历\"{calendar}\"以及所有相应的事件和任务。",
     "This will unshare the calendar \"{calendar}\"." : "这将取消共享日历“{calendar}”。",
     "This will delete the list \"{list}\" and all corresponding tasks." : "这会删除列表 \"{list}\" 和所有相应的任务。",
@@ -85,20 +85,14 @@ OC.L10N.register(
     "Add a task due today to \"{calendar}\"…" : "添加今天截止的任务到 \"{calendar}\" ...",
     "Add a current task to \"{calendar}\"…" : "添加当前任务到 \"{calendar}\" ...",
     "Add a task to \"{calendar}\"…" : "添加任务到 \"{calendar}\" ...",
-    "Load all completed tasks." : "载入所有已完成任务。",
     "Change sort order" : "更改排序",
     "Relevance" : "相关联",
     "Sort by completed state, due date, priority, start date and summary." : "按已完成状态，截止日期，优先级，开始日期及概况排序",
     "Start date" : "开始日期",
-    "Sort by start date and summary." : "按开始日期及概况排序",
     "Due date" : "截止日期",
-    "Sort by due date and summary." : "按到期日及概况排序",
     "Created date" : "创建日期",
-    "Sort by created date and summary." : "按创建日期及概况排序",
     "Last modified" : "上一次更改",
-    "Sort by last-modified date and summary." : "按上次修改时期和摘要排序。",
     "Completed date" : "完成日期",
-    "Sort by completed date." : "按完成日期排序。",
     "Priority" : "优先级",
     "Sort by priority and summary." : "按优先级和摘要排序。",
     "Alphabetically" : "按字母顺序",
@@ -138,13 +132,12 @@ OC.L10N.register(
     "Cancel" : "取消",
     "Create task" : "创建任务",
     "Creating the new task…" : "正在创建新任务…",
-    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" 已被添加至  \"{calendar}\"",
     "Close" : "关闭",
     "Open task" : "打开任务",
+    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" 已被添加至  \"{calendar}\"",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n 任务完成"],
     "Tomorrow" : "明天",
     "Add List…" : "添加列表 ...",
-    "New List" : "新列表",
     "All day" : "所有天",
     "Unpin" : "取消固定",
     "Pin" : "固定",
